.. rst-class:: hide-header


.. image:: _static/logo.jpeg
    :align: center


.. toctree::
   :maxdepth: 3

   ../../README.md
   license

API Documentation
=================

.. toctree::
   :maxdepth: 3

   autoapi/index
